/*========================================================================*\
|                                                                          |
| GANG430.h                                                                |
|                                                                          |
| Definitions for use of GANG430.DLL                                       |
|--------------------------------------------------------------------------|
| Project:          MSP430 FLASH Gang Programmer                           |
| Developed using:  MS Visual C++ 6.0                                      |
|--------------------------------------------------------------------------|
| Author:           RSTO                                                   |
| Version:          1.18                                                   |
| Initial Version:  05/03                                                  |
|--------------------------------------------------------------------------|
| Version history:                                                         |
| 1.00  05/03 FRGR  Initial Version                                        |
| 1.05  11/03 FRGR  Added errors 48 and 49                                 |                                                                          |
| 1.10  11/05 RSTO  Added GetDeviceId()                                    |
|                   Chagned GangLoadImage()                                |
| 1.11  09/07 RSTO  Added flags F_RESTORE_DCO, F_VERIFY_MARGINAL           |
| 1.12  02/07 RSTO  Added flags F_USE_IMAGE0 and F_USE_IMAGE1              |
| 1.13  02/08 RSTO  Added flag C_SELECTIMAGE                               |
| 1.14  02/08 RSTO  Added error code ERR_NO_DEVICE                         |
| 1.15  05/08 RSTO  Added BSL support for F5xx                             |
| 1.16  09/08 RSTO  Changed naming from BlowFuse to SecureDevice		   |
| 1.17  07/09 RSTO  Deleted F_RESTORE_DCO flag                             |
| 1.18  05/10 GCZA  Added GangAppendImage()                                |
|--------------------------------------------------------------------------|
| Designed 2009 by Texas Instruments Germany                               |
\*========================================================================*/

/*------------------------------------------------------------------------*\
| Remarks:                                                                 |
|                                                                          |
\*------------------------------------------------------------------------*/

#pragma once

// Error Codes reported by GANG430 DLL functions
#define ERR_NONE				0		// Operation successful *** must be the first entry ***
#define ERR_COMM				1		// Communication - Frame has errors
#define ERR_OPEN_COMM			2		// Unable to open COM port - already in use?
#define ERR_CLOSE_COMM			3		// Unable to close COM port
#define ERR_SET_COMM_STATE		4		// Unable to modify COM port state
#define ERR_SYNC				5		// Synchronization failed. Programmer connected?
#define ERR_RX_HDR_TIMEOUT		6		// Timeout during operation - Correct COM port selected?
#define ERR_CMD_NOT_COMPLETED	7		// Command did not complete correctly
#define ERR_CMD_FAILED			8		// Command failed, is not defined, or is not allowed
#define ERR_WRONG_BAUDRATE		9		// Wrong baud rate specified
#define ERR_READ_INI			10		// Could not read GANG430.ini
#define ERR_BAD_RECORD			11		// File contains invalid record
#define ERR_FILE_END			12		// Unexpected end of file
#define ERR_FILE_IO				13		// Error during file I/O
#define ERR_FILE_DETECT			14		// Selected file is of unrecognizable format
#define ERR_FILE_OPEN			15		// Unable to open file
#define	ERR_ARGUMENT            16		// Function argument(s) out of range
#define	ERR_VERIFY_MAYFAIL		17		// RAM affected during programming cycle. Verify may fail

// Error Codes reported additionally by GangGetResult() function
#define	ERR_IMAGE_CORRUPTED		31		// Image Memory corrupted or erased
#define	ERR_IMAGE_JTAGPORT		32		// Selftest - No JTAG access to Image Buffer device (obsolete)
#define	ERR_IMAGE_DATAPORT		33		// Selftest - Data connections to Image Buffer device invalid (obsolete)
#define	ERR_IMAGE_HANDSHAKE		34		// Selftest - No access to one ore more Image Buffer devices
#define	ERR_TARGET_JTAGPORT		35		// Selftest - No JTAG access to one or more Target channels
#define ERR_TARGET_VOLTAGE		36		// Selftest - Target Voltage Generator (VCCT) does not work properly
#define	ERR_SYSTEM_VOLTAGE		37		// Selftest - System Voltage (VCC) not in range
#define ERR_BLOWFUSE_VOLTAGE	38		// Selftest - Blow Fuse Voltage (VPP) not in range
#define	ERR_TARGET_NOACCESS		39		// Target not accessible
#define	ERR_VERIFY_FAILED		40		// Verification failed
#define	ERR_NO_PARMS			41		// Main Process Parameters not yet set
#define	ERR_IMAGE_ERASE			42		// Could not erase Image Buffer
#define	ERR_IMAGE_LOAD			43		// Could not load Image Buffer
#define	ERR_PARMS_LOAD			44		// Could not load Main Process Parameters
#define	ERR_SEL_BAUDRATE		45		// Could not select Baud Rate
#define	ERR_SET_VCC				46		// Could not set target voltage - Short circuitry or settling time too small
#define	ERR_WRONG_CMD			47		// Invalid firmware command
#define	ERR_POWER_SUPPLY		48		// Power supply voltage too low
#define	ERR_EXT_VCC_IN			49		// Sense voltage out of range - Check pin MSP_VCC_IN of target connector
#define ERR_WRONG_DEVICE        50      // Wrong target device connected (the ID of device dosn't match)
#define ERR_NO_DEVICE           52      // No target device connected to GANG430
#define ERR_IMAGE_OVERWRITTEN   53      // Code data saved to already used location (overwritten)

// Filetypes
#define FILETYPE_AUTO			0		// filetype auto detect (obsolete)
#define FILETYPE_TI_TXT			1		// filetype ti text
#define FILETYPE_INTEL_HEX		2		// filetype intel hex

// target SFR access
#define SFR_READ				0x00	// read access
#define SFR_WRITE				0x01	// write access, all targets are affected
#define SFR_START				0x02	// start access, halt CPU
#define SFR_STOP				0x04	// stop access, release CPU

// target supply voltage VCCT
#define	VCC_EXT					0		// VCC_MSP output voltage same as MSP_VCC_IN pin input voltage
#define	VCC_OFF					1		// VCC_MSP output voltage is switched off
#define	VCC_NOM					2		// VCC_MSP output voltage same as before modification

// Remote Command definitions for GANG430
#define	C_NOCOMMAND				0x00	// Not a command
#define	C_SETSIGNALS			0x30	// Set signals at target connector of programmer HW
#define C_START					0x31 	// Executes main process
#define	C_DIAGNOSTIC			0x32	// Send result of main process
#define	C_ERASEIMAGE			0x33	// Erase image memory
#define	C_LOADIMAGE				0x34	// Load target code into image memory
#define	C_SELFTEST				0x35	// Apply selftest on programmer HW
#define	C_LOADPARMS				0x36	// Load main process flow control parameters
#define	C_LOADCHKSUM			0x37	// Load image checksum
#define C_SELECTBAUD			0x38	// Select one of five baud rates
#define	C_ERASEFIRM				0x39	// Erase firmware
#define	C_LOADFIRM				0x3A	// Update Firmware
#define	C_EXITUPDATE			0x3B	// Exit generic handler, go to firmware handler
#define	C_PRGMTARGET			0x3C	// Program only one target module (serial number)
#define	C_READTARGET			0x3D	// Readout only one target module
#define	C_SETVCCTARGET			0x3E	// Set Vcc voltage on VCC_MSP pin
#define	C_SFRTARGET				0x3F	// Access SFR of target module
#define	C_SELECTIMAGE           0x50    // Select program image: 0 or 1

// Flag definitions for system parameters which control main process flow
#define	F_ERASE_INFO		 	0x0001	// executes erasure of info memory
#define	F_ERASE_MAIN			0x0002	// executes erasure of main memory
#define	F_ERASE_PINFO			0x0004	// executes erase of protected info memory
#define	F_ERASE_MASS			0x0007	// executes erasure of info and main memory

#define	F_PROGRAM_INFO			0x0008	// executes programming of info memory
#define	F_PROGRAM_MAIN			0x0010	// executes programming of main memory
#define	F_PROGRAM_MASS			0x0018	// executes programming of info and main memory

#define	F_VERIFY				0x0020	// executes verifaction of info and main memory
#define	F_BLOW_FUSE				0x0040	// executes fuse blowing - legacy name
#define	F_SECURE_DEVICE			0x0040	// makes device secure
#define	F_PROGRAM_RAM			0x0080	// executes programming of ram memory

#define	F_ERASE_CHECK_INFO		0x0100	// executes erase check of info memory
#define	F_ERASE_CHECK_MAIN		0x0200	// executes erase check of main memory
#define	F_ERASE_CHECK_PINFO		0x0400	// executes erase check of protected info memory
#define	F_ERASE_CHECK_MASS		0x0700	// executes erase check whole memory

#define F_USE_SBW               0x0800  // use SpyBiWire JTAG interface for this device
#define F_JTAG_SPEED1           0x0000  // fastest JTAG speed mode
#define F_JTAG_SPEED2           0x1000  // faster  JTAG speed mode
#define F_JTAG_SPEED3           0x2000  // slow    JTAG speed mode
#define F_JTAG_SPEED4           0x3000  // slowest JTAG speed mode
#define F_VERIFY_MARGINAL       0x4000  // verify target additionally for marginal '1' and '0'
//not used after v1.47
//#define F_RESTORE_DCO           0x8000  // restore DCO calibration data after erase INFO A
#define F_ERASE_BSL             0x010000  // open BSL for erase/write operations
#define F_ERASE_CHECK_BSL       0x020000  // open BSL for erase/write operations
#define F_PROGRAM_BSL           0x040000  // open BSL for erase/write operations

#define F_VCC_OFF				0x80	// switches target Vcc off after main process

// Flag definitions for affected memory ranges
#define	F_DATA_IN_RAM			0x01	// data in ram area
#define	F_DATA_IN_MAIN			0x02	// data in main area
#define	F_DATA_IN_INFO			0x04	// data in info area

// Type definitions for memory types
#define	T_EOR				    0x00	// end of records, no memory type
#define	T_RAM					0x01	// memory of type ram
#define	T_INFO					0x02	// memory of type information memory
#define	T_MAIN					0x03	// memory of type main memory
#define	T_DUMY					0x04	// memory of type ram (mirrored)
#define	T_PINFO					0x05	// protected (LOCKA) info memory
#define	T_CINFO				    0x06	// for factory data reserved memory
#define	T_BSL				    0x07	// memory of type BSL

// Flag definitions for device configurations
#define	F_MEM_MODEL				0x7F	// memory models 0..127
#define	F_VPP_ON_TEST			0x80	// pin, Vpp is applied to at fuse blowing; 0: VPP on TDI

//-----------------------------------------------------------------------------
//  Internally used definitions

#define	LAMP_HANDLE				0		// handle of status lamp
#define	LAMP_ERROR				1		// handle of bitmap (red)
#define	LAMP_OK					2		// handle of bitmap (green with strike)
#define	LAMP_INFO				3		// handle of bitmap (blue with "i")
#define	LAMP_OFF				4		// handle of bitmap (gray)
#define	LAMP_LAST				4		// number of bitmaps

//-----------------------------------------------------------------------------
//  Internally used functions

// int ProgramTITXTorINTEL(char* lpszFileName, unsigned action);
// void Progress(WORD wAction, LONG wValue);

//-- GangEraseFirmware --------------------------------------------------------
// erases the firmware memory at the programmer unit.
// Arguments: LONG wStart, wLength (the range)
// Result:    LONG (the error code)

LONG WINAPI GangEraseFirmware(LONG wStart, LONG wLength);

//-- GangLoadFirmware ---------------------------------------------------------
// loads the firmware memory at the programmer unit with content of file
// Arguments: LPTSTR (the complete path of the file)
// Result:    LONG (the error code)

LONG WINAPI GangLoadFirmware(LPTSTR lpszFileName);

//-- GangTest -----------------------------------------------------------------
// GangSelftest performs a test sequence for debugging purposes only
// Arguments: LONG (the test)
// Result:    LONG (the error code)

LONG WINAPI GangTest(LONG lIndex);

//-- InitStatusLamp -----------------------------------------------------------
// initializes the handle of the status lamp and the bitmaps of the
// frontend application.
// Arguments: LONG lpStatusLamp (pointer to an array of handle or NULL)
// Result:    LONG (ERR_NONE)

LONG WINAPI InitStatusLamp(LONG *lpStatusLamp);

//-----------------------------------------------------------------------------
// DLL functions

//-- InitProgress -------------------------------------------------------------
// initializes the handle of the status window and the progress bar of the
// frontend application.
// Arguments: LONG hStatusWnd (passes a Window handle or NULL)
//            LONG hProgBar (passes a Window handle or NULL)
// Result:    LONG (ERR_NONE)

LONG WINAPI InitProgress(LONG hStatusWnd, LONG hProgBar);

//-- InitCom ------------------------------------------------------------------
// InitCom opens a communications port, sets the baudrate and checks if the
// GANG430 is present
// Arguments: LPTSTR lpszComPort (the name of the port)
//            LONG lBaudRate (the baud rate)
// Result:    LONG (the error code)

LONG WINAPI InitCom(LPTSTR lpszPort, LONG lBaud);

//-- ReleaseCom ---------------------------------------------------------------
// ReleaseCom releases the communications port
// Arguments: none
// Result:    LONG (the error code)

LONG WINAPI ReleaseCom(void);

//-- GetErrorString -----------------------------------------------------------
// retrieves the pointer to the error string belonging to the error number
// Arguments: LONG lErrorNumber (the error number)
// Result:    CHAR* (the pointer to the error string)

CHAR* WINAPI GetErrorString(LONG lErrorNumber);

//-- GetDevice ----------------------------------------------------------------
// reads all specific parameters of a device type from Gang430.ini and allocate
// them in a buffer pointed to by lpData.
// Arguments: LPTSTR lpszDeviceName (the device name in Gang430.ini)
//            void *lpData (the destination data buffer)
// Result:    LONG (the error code)

LONG WINAPI GetDevice(LPTSTR lpszDeviceName, void **lpData);

//-- GangSelectBaudrate -------------------------------------------------------
// GangSelectBaudrate selects the baudrate of the programmer unit
// Arguments: LONG (the baudrate index: 0 = 9600, 4 = 115200
// Result:    LONG (the error code)

LONG WINAPI GangSelectBaudrate(LONG lBaud);

//-- GangSetVccTarget ---------------------------------------------------------
// sets the target Vcc voltage at the programmer's target connector pin VCC_MSP
// Arguments: LONG (the voltage: 0 = extern, 1 = off, 2 = as loaded with
//                  GangLoadParameters, >17: in 100mV steps (1.8..3.6V)
// Result:    LONG (the error code)

LONG WINAPI GangSetVccTarget(LONG lVoltage);

//-- GangSelftest -------------------------------------------------------------
// GangSelftest performs a selftest of the programmer unit
// Arguments: LONG (the timeout in 100ms)
// Result:    LONG (the error code)

LONG WINAPI GangSelftest(LONG lTime);

//-- GangGetResult ------------------------------------------------------------
// GangGetResult retrieves the detailed results of an operation at the prog. unit
// Arguments: void *lpData (the result's data)
// Result:    LONG (the error code)

LONG WINAPI GangGetResult(void *lpData);

//-- GangLoadParameters -------------------------------------------------------
// GangLoadParameters controls the main process at the programmer unit
// Arguments: LONG lFlags (F_ERASE_MASS, F_ERASE_CHECK_MASS, F_PROGRAM_MASS...)
//            LONG lSupply (Supply voltage in 100mV, max 0x7F, add. F_VCC_OFF=0x80)
//            LONG lVccSettleTime (in milliseconds, max 0xFFFF)
// Result:    LONG (the error code)

LONG WINAPI GangLoadParameters(LONG lFlags, LONG lSupply, LONG lVccSettleTime);

//-- GangMainProcess ----------------------------------------------------------
// GangMainProcess executes the main process at the programmer unit
// Arguments: LONG (the timeout in 100ms)
// Result:    LONG (the error code)

LONG WINAPI GangMainProcess(LONG lTime);

//-- GangAppendImage -----------------------------------------------------------
// GangAppendImage sets the flag that the next code file is added to existing in memory
// image memory is not erased when the Append Image flag is set.
// Append Image flag is cleared when the GangLoadImage is executed.
// Before adding the next Image, the GangAppendImage( void ) should be called again.
// Arguments: none
// Result:    LONG (the error code)

LONG WINAPI GangAppendImage( void );

//-- GangSelectImage -----------------------------------------------------------
// GangSelectImage sets active image to work with. GANG430 supports two images.
// Arguments: LONG lImage (0 or 1, the image number. Default image number is 0)
// Result:    LONG (the error code)

LONG WINAPI GangSelectImage(LONG lImage);

//-- GangEraseImage -----------------------------------------------------------
// GangEraseImage clears (presets with 0xFF) the image memory at the progr. unit
// Arguments: none
// Result:    LONG (the error code)

LONG WINAPI GangEraseImage(void);

//-- GangLoadImage ------------------------------------------------------------
// writes data from a file either of type TI-txt or of type Intel-hex (auto-detect)
// into the programmer's image flash memory. It also writes the memory model
// parameters of the selected device type and the checksums for main and information
// memory into the programmer's flash system memory.
// Arguments: LPTSTR lpszFileName (the full path of the code file)
//                   or NULL if function is calling only for set up of TargetDevice
//            LPTSTR lpszDeviceName (the device name in Gang430.ini)
// Result:    LONG (the error code)

LONG WINAPI GangLoadImage(LPTSTR lpszFileName, LPTSTR lpszDeviceName);


//-- GangSetSignals -----------------------------------------------------------
// sets specified signals on the programmer target connector
// Arguments: LONG (lSignals determines output signals)
//            LONG (lVoltage determines logic high level voltage of signals)
// Result:    LONG (the error code)

LONG WINAPI GangSetSignals(LONG lSignals, LONG lVoltage);

//-- GangProgramTarget --------------------------------------------------------
// programs data into one selectable target
// Arguments: LONG lTarget (the target number 0..7)
//            LONG lStart, lLength (the range)
//            void *lpData (the source data buffer)
// Result:    LONG (the error code)

LONG WINAPI GangProgramTarget(LONG lTarget, LONG lStart, LONG lLength, void *lpData);

//-- GangReadTarget -----------------------------------------------------------
// reads data from one selectable target into a buffer.
// Arguments: LONG lTarget (the target number 0..7)
//            LONG lStart, lLength (the range)
//            void *lpData (the source data buffer)
// Result:    LONG (the error code)

LONG WINAPI GangReadTarget(LONG lTarget, LONG lStart, LONG lLength, void *lpData);


//-- GangReadTargetFile -------------------------------------------------------
// reads data from one selectable target into a file
// Arguments: LONG lTarget (the target number 0..7)
//            LONG lStart, lLength (the range)
//            LPTSTR lpszFileName (the file)
//            LONG iFileType (the file type)
// Result:    LONG (the error code)

LONG WINAPI GangReadTargetFile(LONG lTarget, LONG lStart, LONG lLength,
									LPTSTR lpszFileName, LONG iFileType);

//-- GangAccessTargetSFR ------------------------------------------------------
// accesses one byte or word within the special function register area (SFR) of
// one selectable target. The user has to take care about the memory attributes.
// Read access also can be used over the entire address range.
// Arguments: LONG lTarget (the target number 0..7)
//            LONG iFlags (SFR_READ	0x00; SFR_WRITE	0x01;
//            LONG lAddress (the address to be accessed)
//            void *lpData (data buffer to be read from/written to)
// Result:    LONG (the error code)

LONG WINAPI GangAccessTargetSFR(LONG lTarget, LONG iFlags, LONG lAddress, void* lpData);


//-- GangEraseSegment----------------------------------------------------------
// erases one single segment of fleash memory. If the memory is protected,
// GANG430 will try to unlock it before.
// Arguments: LONG lAddress (the address in the segment to be erased)
// Result:    LONG (the error code)

LONG WINAPI GangEraseSegment(LONG lAddress);


//-- GangGetDeviceId -----------------------------------------------------------
// reads data from one selectable target into a buffer.
// Arguments: LONG lTarget (the target number 0..7)
//            LPTSTR lpszDeviceName (name of connected device)
// Result:    LONG (the error code)

//this function is obsolete! LONG WINAPI GangGetDeviceId(LONG lTarget, LPTSTR lpszDeviceName);
