// (c) by Texas Instruments Incorporated. All Right Reserved.
//*----------------------------------------------------------------
//* All software and related documentation is provided "AS IS" and
//* without warranty or support of any kind and Texas Instruments
//* expressly disclaims all other warranties, express or implied,
//* including, but not limited to, the implied warranties of
//* merchantability and fitness for a particular purpose. Under no
//* circumstances shall Texas Instruments be liable for any
//* incidental, special or consequential damages that result from
//* the use or inability to use the software or related
//* documentation, even if Texas Instruments has been advised of
//* the liability.
//*
//* Unless otherwise stated, software written and copyrighted by
//* Texas Instruments is distributed as "freeware". You may use
//* and modify this software without any charge or restriction.
//* You may distribute to others, as long as the original author
//* is acknowledged.
//*
//*****************************************************************
/*========================================================================*\
|                                                                          |
| DLLtest.c                                                                |
|                                                                          |
| Application main                                                         |
|--------------------------------------------------------------------------|
| Project:              GANG430 DLL: Application example in C language     |
| Developed using:      MS Visual C++ 5.0 (WIN32 Console Application)      |
|--------------------------------------------------------------------------|
| Author:               FRGR                                               |
| Version:              1.0                                                |
| Initial Version:      07/08/03                                           |
| Last Change:          12/04                                              |
|--------------------------------------------------------------------------|
| Version history:                                                         |
| 1.0   Initial version                                                    |
| 1.1   PInfoErase was added to GangLoadImage to fit V1.26                 |
| 1.2   PInfoErase and EraseCheck make fit for v.1.27                      |
|--------------------------------------------------------------------------|
| Designed 2003 by Texas Instruments Incorporated                          |
| modified by Elprotronic Incorporated                                     |
\*========================================================================*/

/*========================================================================*\
| Important:                                                               |
| 1. The GANG430.dll and GANG430.ini files must be in the same directory   |
|    as DLLTEST.exe (copy from main directory).                            |
| 2. Include Lib\GANG430.h into the main application file.                 |
| 3. The MSP-Gang.dll must be in the same directory as DLLTEST.exe         |
\*========================================================================*/

#include <windows.h>
#include <stdio.h>
#include "Lib\GANG430.h"

//--- globals --------------------------------------------------------------
//
#define ComPort		"COM31"
#define Baudrate	115200
#define Dll430		"Lib\\Gang430.dll"	//The dll is loaded correctly
#define FilName		"MyHex.hex"
#define DeviceType  "MSP430 F2481" //	"MSP430 F1232"
#define Action		(F_ERASE_MASS | F_PROGRAM_MASS | F_ERASE_CHECK_MASS | F_VERIFY)
#define Vcc			30					//When I change this value, the image file that I load into the msp gang programmer doesn't care (always 30)
#define SettleTime	200
#define	TestTarget	0
#define Blink		3
#define ERR_NO_DLL	100

BYTE Buffer[40];
BYTE connected;
BYTE overall;
WORD Temp;
LONG status;
char* Readout[8] = {
	".\\Readout1.txt", ".\\Readout2.txt", ".\\Readout3.txt", ".\\Readout4.txt",
    ".\\Readout5.txt", ".\\Readout6.txt", ".\\Readout7.txt", ".\\Readout8.txt"
};

HINSTANCE hDLL430;							// handle of DLL
static FARPROC pInitCom	           = NULL;	// pointer to DLL functions
static FARPROC pReleaseCom	       = NULL;
static FARPROC pGangEraseImage     = NULL;
static FARPROC pGangLoadImage      = NULL;
static FARPROC pGangLoadParameters = NULL;
static FARPROC pGangMainProcess    = NULL;
static FARPROC pGangGetResult      = NULL;
static FARPROC pGetErrorString     = NULL;
static FARPROC pGangAccessTargetSFR= NULL;
static FARPROC pGangProgramTarget  = NULL;
static FARPROC pGangReadTargetFile = NULL;
static FARPROC pGangSelectBaudrate = NULL;
static FARPROC pGangSetVccTarget   = NULL;
static FARPROC pGangSelftest       = NULL;
static FARPROC pGangSetSignals     = NULL;
static FARPROC pGangReadTarget     = NULL;

//--- support functions ----------------------------------------------------
//
void Evaluate(LONG);

void Load_DLL()
{
	printf("Load DLL       %15s", Dll430);
	hDLL430 = LoadLibrary(Dll430);
	if (hDLL430 == NULL)
		Evaluate(ERR_NO_DLL);

	pInitCom            = GetProcAddress(hDLL430, "InitCom");
	pReleaseCom         = GetProcAddress(hDLL430, "ReleaseCom");
	pGangEraseImage     = GetProcAddress(hDLL430, "GangEraseImage");
	pGangLoadImage      = GetProcAddress(hDLL430, "GangLoadImage");
	pGangLoadParameters = GetProcAddress(hDLL430, "GangLoadParameters");
	pGangMainProcess    = GetProcAddress(hDLL430, "GangMainProcess");
	pGangGetResult      = GetProcAddress(hDLL430, "GangGetResult");
	pGetErrorString     = GetProcAddress(hDLL430, "GetErrorString");
	pGangAccessTargetSFR= GetProcAddress(hDLL430, "GangAccessTargetSFR");
	pGangProgramTarget  = GetProcAddress(hDLL430, "GangProgramTarget");
	pGangReadTargetFile = GetProcAddress(hDLL430, "GangReadTargetFile");
	pGangSelectBaudrate = GetProcAddress(hDLL430, "GangSelectBaudrate");
	pGangSetVccTarget   = GetProcAddress(hDLL430, "GangSetVccTarget");
	pGangSelftest       = GetProcAddress(hDLL430, "GangSelftest");
	pGangSetSignals     = GetProcAddress(hDLL430, "GangSetSignals");
	pGangReadTarget     = GetProcAddress(hDLL430, "GangReadTarget");

	Evaluate(ERR_NONE);
}

void Free_DLL()
{
	printf("Detach DLL     %15s", " ");
	if (hDLL430 == NULL)
	{
		Evaluate(ERR_NO_DLL);
	}
	else
	{
		FreeLibrary(hDLL430);
		Evaluate(ERR_NONE);
	}
}

void Wait()
{
	#ifndef _DEBUG
	printf("press any key to continue");
	getch();
	#endif
}

void Exit(int status)
{
	Free_DLL();
	if (status == ERR_NONE)
		printf("\nProgram successfully finished - ");
	else
		printf("\nProgram aborted - ");
	Wait();
	exit(status);
}

void Evaluate(LONG status)
{
	switch(status)
	{
		case ERR_NONE:
			printf("  Operation successful.\n");
			break;
		case ERR_NO_DLL:
			printf("  ERROR: File not found !\n");
			Exit((int)status);
			break;
		default:
			printf("  %s\n", pGetErrorString(status));
			Exit((int)status);
	}
}

//-- Show result of main process -----------------------------------------------
//
void Show_Diagnostic(void)
{
	int i, mask;

	printf("      Target   1-2-3-4-5-6-7-8\n");
	printf("      Process  ");
	for (i=0, mask=1; i<8; i++, mask <<= 1)
	{
		if (connected & mask)
			overall & mask ? printf("1 ") : printf("0 ");
		else
			printf("- ");
	}
	printf("\n");
}

//-- Write serial number to every successfully processed target ---------------
//
void Write_Serial_Number()
{
	int i, number;

	printf("GangProgramTarget (SerNum)     %d ", number);

	for (i=0, number=1; i<8; i++, number++)
	{
		if (overall & (1 << i))
		{
			Buffer[0] = (number >> 8) & 0xFF;
			Buffer[1] = number & 0xFF;
			pGangProgramTarget(i, 0x1080, 2,	Buffer);
		}
	}
	printf("Done\n");
}

//-- Read out serial number from every successfully processed target -----------
//
void Read_Targets_To_File()
{
	int i;

	printf("GangReadTargetFile Readoutx.txt ");

	for (i=0; i<8; i++)
	{
		if (overall & (1 << i))
			pGangReadTargetFile(i, 0x1080, 2, Readout[i], FILETYPE_TI_TXT);
	}
	printf("Done\n");
}

//-- Test hardware of target "TestTarget" --------------------------------------
//
void Test_Targets()
{
	int i;
	WORD wData, wADCval;

	printf("GangAccessTargetSFR (test T1)   ");

	// LED blinks slowly on P1.0 port of target
	wData = 0x00;
	pGangAccessTargetSFR(TestTarget, SFR_WRITE | SFR_START, 0x0026, &wData);// P1SEL (start)
	wData = 0x01;
	pGangAccessTargetSFR(TestTarget, SFR_WRITE, 0x0022, &wData);			// P1DIR
	for (i=0; i<Blink; i++)
	{
		wData = i % 2;														// data is 0x00 or 0x01
		pGangAccessTargetSFR(TestTarget, SFR_WRITE, 0x0021, &wData);		// P1OUT (toggle)
		printf(">");
		Sleep(500);
		printf(">");
		Sleep(500);
	}
	for (i=0; i<Blink; i++) printf("\x08\x08");
	printf("Done                          \n");

//	wADCval = 0xFFFF;
    pGangAccessTargetSFR(TestTarget, SFR_READ, 0x019, &wData);			// read ADC10CTL0
    printf("\nADC10CTL0:   %x", wData);
	printf("\n\n");

	wADCval = 0xF0F0;
	pGangAccessTargetSFR(TestTarget, SFR_WRITE, 0x019, &wADCval);			// ADC10CTL0
	wADCval = 0x5A5A;
	pGangAccessTargetSFR(TestTarget, SFR_WRITE, 0x0170, &wADCval);			// TAR
    pGangAccessTargetSFR(TestTarget, SFR_READ, 0x019, &wData);			// read ADC10CTL0
    printf("\nADC10CTL0:   %x", wData);
	printf("\n\n");
//	pGangAccessTargetSFR(TestTarget, SFR_WRITE, 0x0170, &wADCval);			// TAR
    pGangAccessTargetSFR(TestTarget, SFR_READ, 0x0170, &wData);			// read TAR
    printf("\nTAR:   %x", wData);
	printf("\n\n");
}

//-- Main program --------------------------------------------------------------
//
void main()
{
	printf("GANG430 DLL: Application example in C language\n\n");

	Load_DLL();

	// setup for programmer unit, LED blinking program is loaded
	printf("InitCom        %15s", ComPort);
	status = pInitCom(ComPort, Baudrate);
	Evaluate(status);

	printf("GangEraseImage %15s", " ");
	status = pGangEraseImage();
	Evaluate(status);

	printf("GangLoadImage  %15s", DeviceType);
	status = pGangLoadImage(FilName, DeviceType);
	Evaluate(status);

	printf("GangLoadParms  %14.1fV", (float)(Vcc/10));
	status = pGangLoadParameters(Action, Vcc, SettleTime);
	Evaluate(status);

	// execute main process and show result
	printf("GangMainProcess%15s", " ");
	status = pGangMainProcess(1000);
	Evaluate(status);

	printf("GangGetResult  %15s", " ");
	status = pGangGetResult(&Buffer);
	Evaluate(status);

	connected = Buffer[0];
	overall   = Buffer[4];
	Show_Diagnostic();

	// Write serial number to every successfully processed target
	Write_Serial_Number();

	// Read out serial number from every successfully processed target
	Read_Targets_To_File();

	// Test one port pin (LED on P1.0) of one target
	Test_Targets();

	// release tested target
	Temp = 0x5A80;
	printf("GangAccessTargetSFR (release) ");
	status = pGangAccessTargetSFR(TestTarget, SFR_WRITE | SFR_START | SFR_STOP, 0x120, &Temp);
	Evaluate(status);

	// Release programmer unit
	printf("ReleaseCom     %15s", " ");
	status = pReleaseCom();
    Sleep(5000);

	Evaluate(status);

	// Detach DLL and exit program
	Exit(ERR_NONE);
}
